@@ -27,6 +27,8 @@
 #include <qstring.h>
 #include <qobject.h>
 
+#include "libkdetv_export.h"
+
 class KdetvMixerPlugin;
 class PluginFactory;
 
@@ -36,7 +38,7 @@ class AudioManager : public QObject
 
 public:
     void rescanPlugins();
-    KdetvMixerPlugin *plugin();
+    LIBKDETV_EXPORT KdetvMixerPlugin *plugin();
 
 public slots:
     int setVolume(int left, int right);
