@@ -583,7 +583,7 @@ KdetvView *Kdetv::createScreen( QWidget *parent, const char *name )
     connect(_srcm, SIGNAL(colourKeyChanged(QColor)),
             _osd, SLOT(setColourKey(QColor)));
     connect(_srcm, SIGNAL(colourKeyChanged(QColor)),
-            _view, SLOT(repaint()));
+            _view, SLOT(update()));
 
     // Connect the viewmanager's signals to the slots to propagate configuration changes
     connect(_viewmng, SIGNAL(setFixedAspectRatio(bool, int)),
