@@ -634,7 +634,7 @@ void ChannelIOFormatXML::writeVariant(QDomElement &parent, const QString& name,
 }
 
 extern "C" {
-	ChannelIOFormatXML* create_xmlchannels(Kdetv *ktv)
+	KDETV_EXPORT ChannelIOFormatXML* create_xmlchannels(Kdetv *ktv)
     {
 		return new ChannelIOFormatXML(ktv, 0, "XML Channel Plugin");
 	}
