@@ -406,11 +406,11 @@ const QString& KdetvV4L::defaultAudioMode()
 
     // FIXME: a more intelligent and general algorithm would not hurt...
     if (modes.contains(i18n("Stereo"))) {
-        return modes[modes.findIndex(i18n("Stereo"))];
+        return *modes.at(modes.findIndex(i18n("Stereo")));
     }
 
     if (modes.contains(i18n("Language 1"))) {
-        return modes[modes.findIndex(i18n("Language 1"))];
+        return *modes.at(modes.findIndex(i18n("Language 1")));
     }
 
     return broadcastedAudioModes().first();
@@ -801,7 +801,7 @@ int KdetvV4L::setVideoDesktop(bool on)
         _isVideoDesktop = false;
         stopVideo();
         setMuted(true);
-        _dtReg->repaint();
+        _dtReg->update();
         _w = _winReg;
         delete _vs;
         _vs = new QVideoStream(_w);
@@ -1198,7 +1198,7 @@ bool KdetvV4L::event(QEvent* e)
 // ---------------------------------------------------- Factory
 
 extern "C" {
-    KdetvV4L* create_v4l(Kdetv *ktv, QWidget *w) {
+    KDETV_EXPORT KdetvV4L* create_v4l(Kdetv *ktv, QWidget *w) {
         return new KdetvV4L(ktv, w, "v4l plugin");
     }
 }
