@@ -271,11 +271,11 @@ const QString& KdetvV4L2::defaultAudioMode()
 
     // FIXME: a more intelligent and general algorithm would not hurt...
     if (modes.contains(i18n("Stereo"))) {
-        return modes[modes.findIndex(i18n("Stereo"))];
+        return *modes.at(modes.findIndex(i18n("Stereo")));
     }
 
     if (modes.contains(i18n("Language 1"))) {
-        return modes[modes.findIndex(i18n("Language 1"))];
+        return *modes.at(modes.findIndex(i18n("Language 1")));
     }
 
     return broadcastedAudioModes().first();
@@ -867,7 +867,7 @@ bool KdetvV4L2::event(QEvent* e)
 // ---------------------------------------------------- Factory
 
 extern "C" {
-    KdetvV4L2* create_v4l2(Kdetv *ktv, QWidget *w) {
+    KDETV_EXPORT KdetvV4L2* create_v4l2(Kdetv *ktv, QWidget *w) {
         return new KdetvV4L2(ktv, w, "v4l2 plugin");
     }
 }
